@@ -1,9 +1,9 @@
 """Python methods for interactive with a Pact Mock Service."""
 from .consumer import Consumer
-from .matchers import EachLike, Like, SomethingLike, Term
+from .matchers import EachLike, Like, SomethingLike, Term, Format
 from .pact import Pact
 from .provider import Provider
 from .__version__ import __version__  # noqa: F401
 
 __all__ = ('Consumer', 'EachLike', 'Like', 'Pact', 'Provider', 'SomethingLike',
-           'Term')
+           'Term', 'Format')
